/*******************************************************************************\
 * Copyright (c) 1996, 1997 by Markus Koelblin
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
\*******************************************************************************/

/*******************************************************************************\
 * colors.h                                                                    *
 *                                                                             *
 * Implements X11 colormap routines - mainly for PseudoColor visuals           *
 *                                                                             *
 * Author:  Markus Koelblin (Markus.Koelblin@hadiko.de) 1996, 1997             *
\*******************************************************************************/

#ifndef COLORS_H_INCLUDED
#define COLORS_H_INCLUDED

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>

#if defined(__cplusplus) || defined(c_plusplus)
extern "C" {
#endif

#define RGBVAL_MAX    65535

/* Concerns PseudoColor Displays only */
#define COLORS_MAX    256
#define PLANES_MAX    8


/*******************************************************************************\
 * Functional macros for filling XColor structs                                *
\*******************************************************************************/

#define ASSIGN_XCOLOR(c, p, r, g, b, f) \
    (c).pixel= (p); \
    (c).red=   (r); \
    (c).green= (g); \
    (c).blue=  (b); \
    (c).flags= (f);

#define SET_XCOLOR_RGB(c, r, g, b) \
    (c).red=   (r); \
    (c).green= (g); \
    (c).blue=  (b); \
    (c).flags= DoRed|DoGreen|DoBlue;

/*******************************************************************************/
/* Fill RGB values into XColor struct */

extern void     set_xcolor_rgb( XColor         *color,
				unsigned short red,
				unsigned short green,
				unsigned short blue );

/* Create a read/write colormap */

extern void     create_colormap( Display     *display,
				 Colormap    *colormap,
				 Pixel       *pixels_return,
				 int         n_pixels );

/*******************************************************************************/

#if defined(__cplusplus) || defined(c_plusplus)
}
#endif
#endif /* COLORS_H_INCLUDED */




